@@ -7,9 +7,11 @@ import webservice
 
 
 UA = 'isbntools (gzip)'
+
 SERVICE_URL = 'https://www.googleapis.com/books/v1/volumes?q=isbn+%s&fields='\
     'items/volumeInfo(title,authors,publisher,publishedDate,language)'\
     '&maxResults=1'
+
 OUT_OF_SERVICE = 'out of service'
 
 
@@ -20,7 +22,7 @@ class GOOBQuery(object):
 
     def __init__(self, isbn):
         """
-        Constructor
+        Initializer
         """
         self.isbn = isbn
         data = webservice.query(SERVICE_URL % isbn, UA)
@@ -66,5 +68,5 @@ def query(isbn):
     """
     Command Line API to the class
     """
-    query = GOOBQuery(isbn)
-    return query.records()
+    q = GOOBQuery(isbn)
+    return q.records()
