@@ -7,8 +7,10 @@ from ast import literal_eval
 
 
 UA = 'isbntools (gzip)'
+
 SERVICE_URL = 'http://xisbn.worldcat.org/webservices/xid/isbn/%s?'\
               'method=getEditions&format=python'
+
 OUT_OF_SERVICE = 'Temporarily out of service'
 BOOK_NOT_FOUND = 'No results match your search'
 
@@ -20,7 +22,7 @@ class WCATEdQuery(object):
 
     def __init__(self, isbn):
         """
-        Constructor
+        Initializer
         """
         self.isbn = isbn
         data = webservice.query(SERVICE_URL % isbn, UA)
